@@ -1,4 +1,3 @@
-use crate::config::default_max_fps;
 use serde::{Deserialize, Serialize};
 use std::fmt::Display;
 
@@ -10,8 +9,8 @@ pub struct Renderer {
     pub backend: Backend,
     #[serde(default = "bool::default", rename = "disable-unfocused-render")]
     pub disable_unfocused_render: bool,
-    #[serde(default = "default_max_fps", rename = "max-fps")]
-    pub max_fps: u64,
+    #[serde(default = "Option::default", rename = "target-fps")]
+    pub target_fps: Option<u64>,
 }
 
 #[allow(clippy::derivable_impls)]
@@ -21,7 +20,7 @@ impl Default for Renderer {
             performance: Performance::default(),
             backend: Backend::default(),
             disable_unfocused_render: false,
-            max_fps: default_max_fps(),
+            target_fps: None,
         }
     }
 }
