@@ -1,4 +1,4 @@
-use crate::components::core::orthographic_projection;
+use crate::components::core::{orthographic_projection, uniforms::Uniforms};
 use crate::context::Context;
 use bytemuck::{Pod, Zeroable};
 use std::{borrow::Cow, mem};
@@ -6,41 +6,6 @@ use wgpu::util::DeviceExt;
 
 const INITIAL_QUANTITY: usize = 6;
 
-#[repr(C)]
-#[derive(Debug, Clone, Copy, Zeroable, Pod)]
-struct Uniforms {
-    transform: [f32; 16],
-    scale: f32,
-    _padding: [f32; 3],
-}
-
-impl Uniforms {
-    fn new(transformation: [f32; 16], scale: f32) -> Uniforms {
-        Self {
-            transform: transformation,
-            scale,
-            // Ref: https://github.com/iced-rs/iced/blob/bc62013b6cde52174bf4c4286939cf170bfa7760/wgpu/src/quad.rs#LL295C6-L296C68
-            // Uniforms must be aligned to their largest member,
-            // this uses a mat4x4<f32> which aligns to 16, so align to that
-            _padding: [0.0; 3],
-        }
-    }
-}
-
-impl Default for Uniforms {
-    fn default() -> Self {
-        let identity_matrix: [f32; 16] = [
-            1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0,
-            1.0,
-        ];
-        Self {
-            transform: identity_matrix,
-            scale: 1.0,
-            _padding: [0.0; 3],
-        }
-    }
-}
-
 #[repr(C)]
 #[derive(Clone, Copy, Zeroable, Pod)]
 pub struct Vertex {
