@@ -181,9 +181,6 @@ impl GlyphData {
 pub struct RunData {
     pub span: FragmentStyle,
     pub line: u32,
-    pub hash: u64,
-    pub font: usize,
-    pub coords: (u32, u32),
     pub size: f32,
     // pub whitespace: bool,
     // pub trailing_whitespace: bool,
@@ -198,8 +195,6 @@ pub struct RunData {
 
 #[derive(Clone, Debug, Default)]
 pub struct LayoutData {
-    /// Normalized variation coordinates.
-    pub coords: Vec<i16>,
     /// Simple glyphs.
     pub glyphs: Vec<GlyphData>,
     /// Detailed glyphs.
@@ -216,7 +211,6 @@ pub struct LayoutData {
 
 impl LayoutData {
     pub fn clear(&mut self) {
-        self.coords.clear();
         self.glyphs.clear();
         self.detailed_glyphs.clear();
         self.clusters.clear();
@@ -239,7 +233,6 @@ pub struct LineData {
     pub max_advance: Option<f32>,
     pub runs: (u32, u32),
     pub clusters: (u32, u32),
-    pub hash: u64,
 }
 
 impl LineData {
@@ -427,7 +420,6 @@ fn commit_line(
         width: state.x,
         max_advance,
         explicit_break: explicit,
-        hash: run_data.hash,
         ascent: run_data.ascent.round(),
         descent: run_data.descent.round(),
         leading: (run_data.leading).round() * 2.,
